@@ -1,14 +1,16 @@
-from dataclasses import dataclass
+import attr
 from typing import Optional
 from dapodik import DapodikObject, TingkatPendidikan, MataPelajaran, Kurikulum
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('mata_pelajaran_kurikulum_id',
-          kurikulum=Kurikulum,
-          mata_pelajaran=MataPelajaran,
-          tingkat_pendidikan=TingkatPendidikan)
-@dataclass(eq=False)
+@set_meta(
+    "mata_pelajaran_kurikulum_id",
+    kurikulum=Kurikulum,
+    mata_pelajaran=MataPelajaran,
+    tingkat_pendidikan=TingkatPendidikan,
+)
+@attr.dataclass
 class MataPelajaranKurikulum(DapodikObject):
     mata_pelajaran_kurikulum_id: str
     kurikulum_id: int
