@@ -1,13 +1,15 @@
-from dataclasses import dataclass
+import attr
 from dapodik import DapodikObject, Sekolah, JenisPendaftaran, TahunAjaran
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('pdb_id',
-          sekolah=Sekolah,
-          tahun_ajaran=TahunAjaran,
-          jenis_pendaftaran=JenisPendaftaran)
-@dataclass(eq=False)
+@set_meta(
+    "pdb_id",
+    sekolah=Sekolah,
+    tahun_ajaran=TahunAjaran,
+    jenis_pendaftaran=JenisPendaftaran,
+)
+@attr.dataclass
 class PesertaDidikBaru(DapodikObject):
     sekolah_id: str
     nama_pd: str
