@@ -1,16 +1,18 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject, Sekolah, JenisKeluar, Ptk, TahunAjaran
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('ptk_terdaftar_id',
-          ptk=Ptk,
-          sekolah=Sekolah,
-          tahun_ajaran=TahunAjaran,
-          jenis_keluar=JenisKeluar)
-@dataclass(eq=False)
+@set_meta(
+    "ptk_terdaftar_id",
+    ptk=Ptk,
+    sekolah=Sekolah,
+    tahun_ajaran=TahunAjaran,
+    jenis_keluar=JenisKeluar,
+)
+@attr.dataclass
 class PtkTerdaftar(DapodikObject):
     ptk_terdaftar_id: str
     ptk_id: str
