@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('akreditasi_id')
-@dataclass(eq=False, frozen=True)
+@set_meta("akreditasi_id")
+@attr.dataclass(frozen=True)
 class Akreditasi(DapodikObject):
     akreditasi_id: str
     nama: str
