@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_bank')
-@dataclass(eq=False, frozen=True)
+@set_meta("id_bank")
+@attr.dataclass(frozen=True)
 class Bank(DapodikObject):
     id_bank: str
     nm_bank: str
