@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_biblio')
-@dataclass(eq=False, frozen=True)
+@set_meta("id_biblio")
+@attr.dataclass(frozen=True)
 class Biblio(DapodikObject):
     id_biblio: str
     id_freq: Optional[str]
