@@ -1,10 +1,10 @@
-from dataclasses import dataclass
+import attr
 from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('child_delete_id')
-@dataclass(eq=False, frozen=True)
+@set_meta("child_delete_id")
+@attr.dataclass(frozen=True)
 class ChildDelete(DapodikObject):
     child_delete_id: int
     jumlah: int
