@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_gmd')
-@dataclass(eq=False, frozen=True)
+@set_meta("id_gmd")
+@attr.dataclass(frozen=True)
 class Gmd(DapodikObject):
     id_gmd: str
     nm_gmd: str
