@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_jenis_lk')
-@dataclass(eq=False, frozen=True)
+@set_meta("id_jenis_lk")
+@attr.dataclass(frozen=True)
 class JenisLk(DapodikObject):
     id_jenis_lk: str
     nm_jenis_lk: str
