@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('jenis_rombel')
-@dataclass(eq=False, frozen=True)
+@set_meta("jenis_rombel")
+@attr.dataclass(frozen=True)
 class JenisRombel(DapodikObject):
     jenis_rombel: str
     nm_jenis_rombel: str
