@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject, JenjangPendidikan
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('jurusan_id', jenjang_pendidikan=JenjangPendidikan)
-@dataclass(eq=False, frozen=True)
+@set_meta("jurusan_id", jenjang_pendidikan=JenjangPendidikan)
+@attr.dataclass(frozen=True)
 class Jurusan(DapodikObject):
     jurusan_id: str
     nama_jurusan: str
