@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject, Jurusan
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('mata_pelajaran_id', jurusan=Jurusan)
-@dataclass(eq=False, frozen=True)
+@set_meta("mata_pelajaran_id", jurusan=Jurusan)
+@attr.dataclass(frozen=True)
 class MataPelajaran(DapodikObject):
     mata_pelajaran_id: int
     nama: str
