@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject, BlockGrant
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('alat_dari_blockgrant_id', blockgrant=BlockGrant)
-@dataclass(eq=False)
+@set_meta("alat_dari_blockgrant_id", blockgrant=BlockGrant)
+@attr.dataclass
 class AlatDariBlockgrant(DapodikObject):
     blockgrant_id: str
     id_alat: str
@@ -16,5 +16,5 @@ class AlatDariBlockgrant(DapodikObject):
     last_sync: datetime
     updater_id: str
     blockgrant_id_str: str
-    id_alat_str: str = ''
-    alat_dari_blockgrant_id: Optional[str] = 'Admin.model.AlatDariBlockgrant-1'
+    id_alat_str: str = ""
+    alat_dari_blockgrant_id: Optional[str] = "Admin.model.AlatDariBlockgrant-1"
