@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject, Sekolah, Ptk, JenisSarana
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_angkutan', sekolah=Sekolah, ptk=Ptk, jenis_sarana=JenisSarana)
-@dataclass(eq=False)
+@set_meta("id_angkutan", sekolah=Sekolah, ptk=Ptk, jenis_sarana=JenisSarana)
+@attr.dataclass
 class Angkutan(DapodikObject):
     id_angkutan: str
     sekolah_id: str
