@@ -1,11 +1,11 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from dapodik import DapodikObject, BlockGrant
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('bangunan_dari_blockgrant_id', blockgrant=BlockGrant)
-@dataclass(eq=False)
+@set_meta("bangunan_dari_blockgrant_id", blockgrant=BlockGrant)
+@attr.dataclass
 class BangunanDariBlockgrant(DapodikObject):
     blockgrant_id: str
     id_bangunan: str
