@@ -1,11 +1,11 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from dapodik import DapodikObject, Semester
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('buku_longitudinal_id', semester=Semester)
-@dataclass(eq=False)
+@set_meta("buku_longitudinal_id", semester=Semester)
+@attr.dataclass
 class BukuLongitudinal(DapodikObject):
     id_buku: str
     semester_id: str
