@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject, Sekolah, JenisPrasarana
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_tanah', jenis_prasarana=JenisPrasarana, sekolah=Sekolah)
-@dataclass(eq=False)
+@set_meta("id_tanah", jenis_prasarana=JenisPrasarana, sekolah=Sekolah)
+@attr.dataclass
 class Tanah(DapodikObject):
     id_tanah: str
     jenis_prasarana_id: int
