@@ -1,14 +1,13 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime, date
 from dapodik import DapodikObject, Sekolah, KebutuhanKhusus, Jurusan
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('jurusan_sp_id',
-          sekolah=Sekolah,
-          kebutuhan_khusus=KebutuhanKhusus,
-          jurusan=Jurusan)
-@dataclass(eq=False, frozen=True)
+@set_meta(
+    "jurusan_sp_id", sekolah=Sekolah, kebutuhan_khusus=KebutuhanKhusus, jurusan=Jurusan
+)
+@attr.dataclass(frozen=True)
 class JurusanSp(DapodikObject):
     jurusan_sp_id: str
     sekolah_id: str
