@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject, Sekolah
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_pi', sekolah=Sekolah)
-@dataclass(eq=False)
+@set_meta("id_pi", sekolah=Sekolah)
+@attr.dataclass
 class ProgramInklusi(DapodikObject):
     id_pi: str
     sekolah_id: str
