@@ -1,4 +1,4 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from dapodik import (
     Sekolah,
@@ -12,14 +12,16 @@ from dapodik import (
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('sekolah_id',
-          sekolah=Sekolah,
-          kategori_tk=KategoriTk,
-          klasifikasi_lembaga=KlasifikasiLembaga,
-          sumber_dana_sekolah=SumberDanaSekolah,
-          fasilitas_layanan=FasilitasLayanan,
-          lembaga_pengangkat=LembagaPengangkat)
-@dataclass(eq=False)
+@set_meta(
+    "sekolah_id",
+    sekolah=Sekolah,
+    kategori_tk=KategoriTk,
+    klasifikasi_lembaga=KlasifikasiLembaga,
+    sumber_dana_sekolah=SumberDanaSekolah,
+    fasilitas_layanan=FasilitasLayanan,
+    lembaga_pengangkat=LembagaPengangkat,
+)
+@attr.dataclass
 class SekolahPaud(DapodikObject):
     sekolah_id: str
     kategori_tk_id: str
